stereo.tools.DimReduce
======================

.. currentmodule:: stereo.tools

.. autoclass:: DimReduce

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DimReduce.__init__
      ~DimReduce.add_result
      ~DimReduce.check_param
      ~DimReduce.fit
      ~DimReduce.get_params
      ~DimReduce.sparse2array
   
   

   
   
   